@@ -104,6 +104,7 @@ def test_set_response_status_code_generic_reason():
     assert res.status_code == 299
     assert res.status == '299 Success'
 
+
 def test_content_type():
     r = Response()
     # default ctype and charset
@@ -121,6 +122,21 @@ def test_init_content_type_w_charset():
     v = 'text/plain;charset=ISO-8859-1'
     eq_(Response(content_type=v).headers['content-type'], v)
 
+def test_init_adds_default_charset_when_not_json():
+    content_type = 'text/plain'
+    expected = 'text/plain; charset=UTF-8'
+    eq_(Response(content_type=content_type).headers['content-type'], expected)
+
+def test_init_no_charset_when_json():
+    content_type = 'application/json'
+    expected = content_type
+    eq_(Response(content_type=content_type).headers['content-type'], expected)
+
+def test_init_keeps_specified_charset_when_json():
+    content_type = 'application/json;charset=ISO-8859-1'
+    expected = content_type
+    eq_(Response(content_type=content_type).headers['content-type'], expected)
+
 
 def test_cookies():
     res = Response()
@@ -481,6 +497,20 @@ def test_from_file_not_unicode_headers():
     res = Response.from_file(inp)
     eq_(res.headerlist[0][0].__class__, str)
 
+def test_file_with_http_version():
+    inp = io.BytesIO(b'HTTP/1.1 200 OK\r\n\r\nSome data...')
+
+    res = Response.from_file(inp)
+    eq_(res.status_code, 200)
+    eq_(res.status, '200 OK')
+
+def test_file_with_http_version_more_status():
+    inp = io.BytesIO(b'HTTP/1.1 404 Not Found\r\n\r\nSome data...')
+
+    res = Response.from_file(inp)
+    assert res.status_code == 404
+    assert res.status == '404 Not Found'
+
 def test_set_status():
     res = Response()
     res.status = "200"
@@ -769,6 +799,36 @@ def test_set_cookie_expires_is_timedelta_and_max_age_is_None():
     eq_(val[2], 'a=1')
     assert val[3].startswith('expires')
 
+def test_set_cookie_expires_is_datetime_tz_and_max_age_is_None():
+    import datetime
+    res = Response()
+
+    class FixedOffset(datetime.tzinfo):
+        def __init__(self, offset, name):
+            self.__offset = datetime.timedelta(minutes=offset)
+            self.__name = name
+
+        def utcoffset(self, dt):
+            return self.__offset
+
+        def tzname(self, dt):
+            return self.__name
+
+        def dst(self, dt):
+            return datetime.timedelta(0)
+
+    then = datetime.datetime.now(FixedOffset(60, 'UTC+1')) + datetime.timedelta(days=1)
+
+    res.set_cookie('a', '1', expires=then)
+    assert res.headerlist[-1][0] == 'Set-Cookie'
+    val = [x.strip() for x in res.headerlist[-1][1].split(';')]
+    assert len(val) == 4
+    val.sort()
+    assert val[0] in ('Max-Age=86399', 'Max-Age=86400')
+    assert val[1] == 'Path=/'
+    assert val[2] == 'a=1'
+    assert val[3].startswith('expires')
+
 def test_delete_cookie():
     res = Response()
     res.headers['Set-Cookie'] = 'a=2; Path=/'
