@@ -1,5 +1,4 @@
 import binascii
-import cgi
 import io
 import os
 import re
@@ -39,6 +38,7 @@ from webob.compat import (
     url_unquote,
     quote_plus,
     urlparse,
+    cgi_FieldStorage
     )
 
 from webob.cookies import RequestCookies
@@ -59,7 +59,6 @@ from webob.descriptors import (
     serialize_int,
     serialize_range,
     upath_property,
-    deprecated_property,
     )
 
 from webob.etag import (
@@ -220,7 +219,7 @@ class BaseRequest(object):
         )
 
         if content_type == 'application/x-www-form-urlencoded':
-            r.body = bytes_(t.transcode_query(native_(r.body)))
+            r.body = bytes_(t.transcode_query(native_(self.body)))
             return r
         elif content_type != 'multipart/form-data':
             return r
@@ -229,13 +228,13 @@ class BaseRequest(object):
         fs_environ.setdefault('CONTENT_LENGTH', '0')
         fs_environ['QUERY_STRING'] = ''
         if PY3: # pragma: no cover
-            fs = cgi.FieldStorage(fp=self.body_file,
+            fs = cgi_FieldStorage(fp=self.body_file,
                                   environ=fs_environ,
                                   keep_blank_values=True,
                                   encoding=charset,
                                   errors=errors)
         else:
-            fs = cgi.FieldStorage(fp=self.body_file,
+            fs = cgi_FieldStorage(fp=self.body_file,
                                   environ=fs_environ,
                                   keep_blank_values=True)
 
@@ -775,7 +774,7 @@ class BaseRequest(object):
             if body_file is self.body_file_raw:
                 return vars
         content_type = self.content_type
-        if ((self.method == 'PUT' and not content_type)
+        if ((self.method != 'POST' and not content_type)
             or content_type not in
                 ('',
                  'application/x-www-form-urlencoded',
@@ -795,14 +794,14 @@ class BaseRequest(object):
         fs_environ.setdefault('CONTENT_LENGTH', '0')
         fs_environ['QUERY_STRING'] = ''
         if PY3: # pragma: no cover
-            fs = cgi.FieldStorage(
+            fs = cgi_FieldStorage(
                 fp=self.body_file,
                 environ=fs_environ,
                 keep_blank_values=True,
                 encoding='utf8')
             vars = MultiDict.from_fieldstorage(fs)
         else:
-            fs = cgi.FieldStorage(
+            fs = cgi_FieldStorage(
                 fp=self.body_file,
                 environ=fs_environ,
                 keep_blank_values=True)
@@ -1161,14 +1160,6 @@ class BaseRequest(object):
         # HTTP clearly specifies CRLF
         return b'\r\n'.join(parts)
 
-    def as_string(self, skip_body=False):
-        # TODO: Remove in 1.4
-        warn_deprecation(
-            "Please use req.as_bytes",
-            '1.3',
-            self._setattr_stacklevel
-            )
-
     def as_text(self):
         bytes = self.as_bytes()
         return bytes.decode(self.charset)
@@ -1187,15 +1178,6 @@ class BaseRequest(object):
             raise ValueError("The string contains more data than expected")
         return r
 
-    @classmethod
-    def from_string(cls, b):
-        # TODO: Remove in 1.4
-        warn_deprecation(
-            "Please use req.from_bytes",
-            '1.3',
-            cls._setattr_stacklevel
-            )
-
     @classmethod
     def from_text(cls, s):
         b = bytes_(s, 'utf-8')
@@ -1563,7 +1545,7 @@ def _cgi_FieldStorage__repr__patch(self):
         return "FieldStorage(%r, %r)" % (self.name, self.filename)
     return "FieldStorage(%r, %r, %r)" % (self.name, self.filename, self.value)
 
-cgi.FieldStorage.__repr__ = _cgi_FieldStorage__repr__patch
+cgi_FieldStorage.__repr__ = _cgi_FieldStorage__repr__patch
 
 class FakeCGIBody(io.RawIOBase):
     def __init__(self, vars, content_type):
@@ -1631,8 +1613,9 @@ def _encode_multipart(vars, content_type, fout=None):
         w(b'--')
         wt(boundary)
         w(CRLF)
-        assert name is not None, 'Value associated with no name: %r' % value
-        wt('Content-Disposition: form-data; name="%s"' % name)
+        wt('Content-Disposition: form-data')
+        if name is not None:
+            wt('; name="%s"' % name)
         filename = None
         if getattr(value, 'filename', None):
             filename = value.filename
@@ -1714,7 +1697,11 @@ class Transcoder(object):
         if PY3: # pragma: no cover
             decode = lambda b: b
         else:
-            decode = lambda b: b.decode(self.charset, self.errors)
+            def decode(b):
+                if b is not None:
+                    return b.decode(self.charset, self.errors)
+                else:
+                    return b
         data = []
         for field in fs.list or ():
             field.name = decode(field.name)
@@ -1731,11 +1718,3 @@ class Transcoder(object):
             fout=io.BytesIO()
         )
         return fout
-
-# TODO: remove in 1.4
-for _name in 'GET POST params cookies'.split():
-    _str_name = 'str_'+_name
-    _prop = deprecated_property(
-        None, _str_name,
-        "disabled starting WebOb 1.2, use %s instead" % _name, '1.2')
-    setattr(BaseRequest, _str_name, _prop)
